'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _d3Selection = require('d3-selection');

var tooltip = function tooltip(_) {

  var tip = null;
  var size = null;

  /**
   * Create and/or setup the tooltip element
   * @return {Void}
   */
  var create = function create(_) {
    tip = document.querySelector('.wsdm-tooltip');

    if (!tip) {
      tip = document.createElement('div');
      tip.className = 'wsdm-tooltip n';
      document.body.appendChild(tip);
    }
  };

  /**
   * Show the tooltip with the specified content
   * @param  {String} content tooltip's content
   * @return {Void}
   */
  var show = function show(content) {
    tip.style.display = 'block';
    tip.innerHTML = '<div>' + content + '</div>';

    // Measure the size
    tip.style.position = 'static';
    size = tip.getBoundingClientRect();
    tip.style.position = 'absolute';
  };

  /**
   * Hide the tooltip
   * @return {Void}
   */
  var hide = function hide(_) {
    tip.innerHTML = '';
    tip.style.display = 'none';
    size = null;
  };

  /**
   * Position the tooltip on the page
   * based on the d3 event mouse position
   * @param  {Object} event d3 current event, optional
   * @return {Void}
   */
  var position = function position(e) {
    if (!tip || !size) return;

    var _ref = e || _d3Selection.event;

    var pageX = _ref.pageX;
    var pageY = _ref.pageY;
    var _size = size;
    var width = _size.width;
    var height = _size.height;


    tip.style.left = pageX - width / 2 + 'px';
    tip.style.top = pageY - height - 20 + 'px';

    // Make sure positioning didn't change the size
    // if so, set it again
    var newSize = tip.getBoundingClientRect();
    if (newSize.width !== width || newSize.height !== height) {
      size = newSize;
      position(e);
    }
  };

  return {
    create: create,
    show: show,
    hide: hide,
    position: position
  };
};

exports.default = tooltip;